Crate datahugger

Crate datahugger 

Re-exports

pub use crawler::crawl;

Modules

crawler
datasets
error

Structs

CrawlPath
A logical crawl path used to track the current location during repository crawling.
Dataset
DirMeta
FileMeta

Enums

Checksum
Entry
Hasher

Traits

CrawlExt
DatasetBackend
DownloadExt

Functions

json_extract
Retrieves a value from a serde_json::Value by following a dot-separated path and deserializes it into the requested type.
resolve
Errors
resolve_doi_to_url