pub struct FileFilter { /* private fields */ }Expand description
A compiled pair of include/exclude glob sets for filtering file entries by relative path.
- An empty
includesset matches everything. - A file passes the filter when it matches the include rules (or there are none) and does not match any exclude rule.
Implementations
Sourceimpl FileFilter
impl FileFilter
Sourcepub fn new<P>(includes: &[P], excludes: &[P]) -> Result<Self, Error>
pub fn new<P>(includes: &[P], excludes: &[P]) -> Result<Self, Error>
Creates a filter from include and exclude pattern lists.
Errors
Returns an error if any pattern is invalid.
Sourcepub fn matches(&self, path: &str) -> bool
pub fn matches(&self, path: &str) -> bool
Returns true if the given relative path passes the filter.
A path passes when it is included (or no include rules are set) and it is not excluded.
Sourcepub fn is_accept_all(&self) -> bool
pub fn is_accept_all(&self) -> bool
Returns true if this filter accepts all files
(no include and no exclude rules).