Re-exports
pub use crawler::crawl;
Modules
Structs
- Crawl
Path - A logical crawl path used to track the current location during repository crawling.
- Dataset
- DirMeta
- File
Meta
Enums
Traits
Functions
- json_
extract - Retrieves a value from a
serde_json::Valueby following a dot-separated path and deserializes it into the requested type. - resolve
- Errors
- resolve_
doi_ to_ url